==> kubernetes-model-metrics-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/ContainerMetricsBuilder.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerMetricsBuilder extends io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsBuilder>{
  public ContainerMetricsBuilder() {
    this(false);
  }
  public ContainerMetricsBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerMetrics(), validationEnabled);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerMetrics(), validationEnabled);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this(fluent, instance, false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withUsage(instance.getUsage()); 
    this.validationEnabled = validationEnabled; 
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this(instance,false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withUsage(instance.getUsage()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics build() {
    ContainerMetrics buildable = new ContainerMetrics(fluent.getName(),fluent.getUsage());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerMetricsBuilder that = (ContainerMetricsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-metrics-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/metrics/v1beta1/ContainerMetricsBuilder.java <==
package io.fabric8.kubernetes.api.model.metrics.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ContainerMetricsBuilder extends io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluentImpl<io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsBuilder>{
  public ContainerMetricsBuilder() {
    this(false);
  }
  public ContainerMetricsBuilder(java.lang.Boolean validationEnabled) {
    this(new ContainerMetrics(), validationEnabled);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent) {
    this(fluent, false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ContainerMetrics(), validationEnabled);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this(fluent, instance, false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent,io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withUsage(instance.getUsage()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance) {
    this(instance,false);
  }
  public ContainerMetricsBuilder(io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withUsage(instance.getUsage()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetricsFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.metrics.v1beta1.ContainerMetrics build() {
    ContainerMetrics buildable = new ContainerMetrics(fluent.getName(),fluent.getUsage());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContainerMetricsBuilder that = (ContainerMetricsBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
